=======
History
=======

0.1.6 (2022-12-16)
------------------
* Removed stimela2 as a dependency


0.1.5 (2022-12-7)
------------------
* Fixes error with ones rather than zero in the background


0.1.4 (2022-10-26)
------------------
* Fix naming of Stokes parameters


0.1.3 (2022-09-22)
------------------
Switched from `argparse` to `click`
Adds `scabha` as dependency
Introduced schemas for commandline setup


0.1.2 (2022-09-14)
------------------
* Added `output-prefix` argument
* Removed `output-dir` argument


0.1.0 (2022-09-12)
------------------
* First release on PyPI.
